# coding: utf-8

"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kaistack.clients.openapi_clients.pipelinecomponents
from kaistack.clients.openapi_clients.pipelinecomponents.api.pipeline_component_service_api import PipelineComponentServiceApi  # noqa: E501
from kaistack.clients.openapi_clients.pipelinecomponents.rest import ApiException


class TestPipelineComponentServiceApi(unittest.TestCase):
    """PipelineComponentServiceApi unit test stubs"""

    def setUp(self):
        self.api = kaistack.clients.openapi_clients.pipelinecomponents.api.pipeline_component_service_api.PipelineComponentServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_component(self):
        """Test case for create_component

        """
        pass

    def test_delete_component(self):
        """Test case for delete_component

        """
        pass

    def test_get_component(self):
        """Test case for get_component

        """
        pass

    def test_get_component_by_name(self):
        """Test case for get_component_by_name

        """
        pass

    def test_list_component_versions(self):
        """Test case for list_component_versions

        """
        pass

    def test_list_components(self):
        """Test case for list_components

        """
        pass

    def test_update_component(self):
        """Test case for update_component

        """
        pass


if __name__ == '__main__':
    unittest.main()
