# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipelinecomponentapis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pipelinecomponentapis.proto',
  package='codegen',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x1bpipelinecomponentapis.proto\x12\x07\x63odegen\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x93\x01\n\x11PipelineComponent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0f\n\x07\x63reator\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x10\n\x08helpLink\x18\x07 \x01(\t\x12\x0c\n\x04spec\x18\x08 \x01(\t\"!\n\x13GetComponentRequest\x12\n\n\x02id\x18\x01 \x01(\t\"T\n\x14GetComponentResponse\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"#\n\x15ListComponentsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"W\n\x16ListComponentsResponse\x12.\n\ncomponents\x18\x01 \x03(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"G\n\x16\x43reateComponentRequest\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\"W\n\x17\x43reateComponentResponse\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"G\n\x16UpdateComponentRequest\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\"W\n\x17UpdateComponentResponse\x12-\n\tcomponent\x18\x01 \x01(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"*\n\x1cListComponentVersionsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"^\n\x1dListComponentVersionsResponse\x12.\n\ncomponents\x18\x01 \x03(\x0b\x32\x1a.codegen.PipelineComponent\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"$\n\x16\x44\x65leteComponentRequest\x12\n\n\x02id\x18\x01 \x01(\t\"9\n\x17\x44\x65leteComponentResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t2\x93\x06\n\x18PipelineComponentService\x12j\n\x0eListComponents\x12\x16.google.protobuf.Empty\x1a\x1f.codegen.ListComponentsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/pipeline/components\x12r\n\rGetComponents\x12\x1c.codegen.GetComponentRequest\x1a\x1d.codegen.GetComponentResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/pipeline/components/{id}\x12\x80\x01\n\x0f\x43reateComponent\x12\x1f.codegen.CreateComponentRequest\x1a .codegen.CreateComponentResponse\"*\x82\xd3\xe4\x93\x02$\"\x17/v1/pipeline/components:\tcomponent\x12\x80\x01\n\x0fUpdateComponent\x12\x1f.codegen.UpdateComponentRequest\x1a .codegen.UpdateComponentResponse\"*\x82\xd3\xe4\x93\x02$\x1a\x17/v1/pipeline/components:\tcomponent\x12\x94\x01\n\x15ListComponentVersions\x12%.codegen.ListComponentVersionsRequest\x1a&.codegen.ListComponentVersionsResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/pipeline/components/verions/{id}\x12z\n\x0f\x44\x65leteComponent\x12\x1f.codegen.DeleteComponentRequest\x1a .codegen.DeleteComponentResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1/pipeline/components/{id}b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_PIPELINECOMPONENT = _descriptor.Descriptor(
  name='PipelineComponent',
  full_name='codegen.PipelineComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.PipelineComponent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='codegen.PipelineComponent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='codegen.PipelineComponent.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='codegen.PipelineComponent.image', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creator', full_name='codegen.PipelineComponent.creator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='codegen.PipelineComponent.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='helpLink', full_name='codegen.PipelineComponent.helpLink', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='codegen.PipelineComponent.spec', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=280,
)


_GETCOMPONENTREQUEST = _descriptor.Descriptor(
  name='GetComponentRequest',
  full_name='codegen.GetComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.GetComponentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=315,
)


_GETCOMPONENTRESPONSE = _descriptor.Descriptor(
  name='GetComponentResponse',
  full_name='codegen.GetComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.GetComponentResponse.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.GetComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=401,
)


_LISTCOMPONENTSREQUEST = _descriptor.Descriptor(
  name='ListComponentsRequest',
  full_name='codegen.ListComponentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.ListComponentsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=438,
)


_LISTCOMPONENTSRESPONSE = _descriptor.Descriptor(
  name='ListComponentsResponse',
  full_name='codegen.ListComponentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='codegen.ListComponentsResponse.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.ListComponentsResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=527,
)


_CREATECOMPONENTREQUEST = _descriptor.Descriptor(
  name='CreateComponentRequest',
  full_name='codegen.CreateComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.CreateComponentRequest.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=600,
)


_CREATECOMPONENTRESPONSE = _descriptor.Descriptor(
  name='CreateComponentResponse',
  full_name='codegen.CreateComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.CreateComponentResponse.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.CreateComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=689,
)


_UPDATECOMPONENTREQUEST = _descriptor.Descriptor(
  name='UpdateComponentRequest',
  full_name='codegen.UpdateComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.UpdateComponentRequest.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=762,
)


_UPDATECOMPONENTRESPONSE = _descriptor.Descriptor(
  name='UpdateComponentResponse',
  full_name='codegen.UpdateComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='codegen.UpdateComponentResponse.component', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.UpdateComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=851,
)


_LISTCOMPONENTVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListComponentVersionsRequest',
  full_name='codegen.ListComponentVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.ListComponentVersionsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=895,
)


_LISTCOMPONENTVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListComponentVersionsResponse',
  full_name='codegen.ListComponentVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='codegen.ListComponentVersionsResponse.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.ListComponentVersionsResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=991,
)


_DELETECOMPONENTREQUEST = _descriptor.Descriptor(
  name='DeleteComponentRequest',
  full_name='codegen.DeleteComponentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='codegen.DeleteComponentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1029,
)


_DELETECOMPONENTRESPONSE = _descriptor.Descriptor(
  name='DeleteComponentResponse',
  full_name='codegen.DeleteComponentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='codegen.DeleteComponentResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='codegen.DeleteComponentResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1088,
)

_GETCOMPONENTRESPONSE.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_LISTCOMPONENTSRESPONSE.fields_by_name['components'].message_type = _PIPELINECOMPONENT
_CREATECOMPONENTREQUEST.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_CREATECOMPONENTRESPONSE.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_UPDATECOMPONENTREQUEST.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_UPDATECOMPONENTRESPONSE.fields_by_name['component'].message_type = _PIPELINECOMPONENT
_LISTCOMPONENTVERSIONSRESPONSE.fields_by_name['components'].message_type = _PIPELINECOMPONENT
DESCRIPTOR.message_types_by_name['PipelineComponent'] = _PIPELINECOMPONENT
DESCRIPTOR.message_types_by_name['GetComponentRequest'] = _GETCOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['GetComponentResponse'] = _GETCOMPONENTRESPONSE
DESCRIPTOR.message_types_by_name['ListComponentsRequest'] = _LISTCOMPONENTSREQUEST
DESCRIPTOR.message_types_by_name['ListComponentsResponse'] = _LISTCOMPONENTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateComponentRequest'] = _CREATECOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['CreateComponentResponse'] = _CREATECOMPONENTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateComponentRequest'] = _UPDATECOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateComponentResponse'] = _UPDATECOMPONENTRESPONSE
DESCRIPTOR.message_types_by_name['ListComponentVersionsRequest'] = _LISTCOMPONENTVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListComponentVersionsResponse'] = _LISTCOMPONENTVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteComponentRequest'] = _DELETECOMPONENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteComponentResponse'] = _DELETECOMPONENTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PipelineComponent = _reflection.GeneratedProtocolMessageType('PipelineComponent', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINECOMPONENT,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.PipelineComponent)
  })
_sym_db.RegisterMessage(PipelineComponent)

GetComponentRequest = _reflection.GeneratedProtocolMessageType('GetComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.GetComponentRequest)
  })
_sym_db.RegisterMessage(GetComponentRequest)

GetComponentResponse = _reflection.GeneratedProtocolMessageType('GetComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.GetComponentResponse)
  })
_sym_db.RegisterMessage(GetComponentResponse)

ListComponentsRequest = _reflection.GeneratedProtocolMessageType('ListComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTSREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentsRequest)
  })
_sym_db.RegisterMessage(ListComponentsRequest)

ListComponentsResponse = _reflection.GeneratedProtocolMessageType('ListComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTSRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentsResponse)
  })
_sym_db.RegisterMessage(ListComponentsResponse)

CreateComponentRequest = _reflection.GeneratedProtocolMessageType('CreateComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.CreateComponentRequest)
  })
_sym_db.RegisterMessage(CreateComponentRequest)

CreateComponentResponse = _reflection.GeneratedProtocolMessageType('CreateComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.CreateComponentResponse)
  })
_sym_db.RegisterMessage(CreateComponentResponse)

UpdateComponentRequest = _reflection.GeneratedProtocolMessageType('UpdateComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.UpdateComponentRequest)
  })
_sym_db.RegisterMessage(UpdateComponentRequest)

UpdateComponentResponse = _reflection.GeneratedProtocolMessageType('UpdateComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.UpdateComponentResponse)
  })
_sym_db.RegisterMessage(UpdateComponentResponse)

ListComponentVersionsRequest = _reflection.GeneratedProtocolMessageType('ListComponentVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTVERSIONSREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentVersionsRequest)
  })
_sym_db.RegisterMessage(ListComponentVersionsRequest)

ListComponentVersionsResponse = _reflection.GeneratedProtocolMessageType('ListComponentVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPONENTVERSIONSRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.ListComponentVersionsResponse)
  })
_sym_db.RegisterMessage(ListComponentVersionsResponse)

DeleteComponentRequest = _reflection.GeneratedProtocolMessageType('DeleteComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMPONENTREQUEST,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.DeleteComponentRequest)
  })
_sym_db.RegisterMessage(DeleteComponentRequest)

DeleteComponentResponse = _reflection.GeneratedProtocolMessageType('DeleteComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMPONENTRESPONSE,
  '__module__' : 'pipelinecomponentapis_pb2'
  # @@protoc_insertion_point(class_scope:codegen.DeleteComponentResponse)
  })
_sym_db.RegisterMessage(DeleteComponentResponse)



_PIPELINECOMPONENTSERVICE = _descriptor.ServiceDescriptor(
  name='PipelineComponentService',
  full_name='codegen.PipelineComponentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1091,
  serialized_end=1878,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListComponents',
    full_name='codegen.PipelineComponentService.ListComponents',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTCOMPONENTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/pipeline/components',
  ),
  _descriptor.MethodDescriptor(
    name='GetComponents',
    full_name='codegen.PipelineComponentService.GetComponents',
    index=1,
    containing_service=None,
    input_type=_GETCOMPONENTREQUEST,
    output_type=_GETCOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1/pipeline/components/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='CreateComponent',
    full_name='codegen.PipelineComponentService.CreateComponent',
    index=2,
    containing_service=None,
    input_type=_CREATECOMPONENTREQUEST,
    output_type=_CREATECOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\027/v1/pipeline/components:\tcomponent',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateComponent',
    full_name='codegen.PipelineComponentService.UpdateComponent',
    index=3,
    containing_service=None,
    input_type=_UPDATECOMPONENTREQUEST,
    output_type=_UPDATECOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002$\032\027/v1/pipeline/components:\tcomponent',
  ),
  _descriptor.MethodDescriptor(
    name='ListComponentVersions',
    full_name='codegen.PipelineComponentService.ListComponentVersions',
    index=4,
    containing_service=None,
    input_type=_LISTCOMPONENTVERSIONSREQUEST,
    output_type=_LISTCOMPONENTVERSIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/v1/pipeline/components/verions/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteComponent',
    full_name='codegen.PipelineComponentService.DeleteComponent',
    index=5,
    containing_service=None,
    input_type=_DELETECOMPONENTREQUEST,
    output_type=_DELETECOMPONENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\036*\034/v1/pipeline/components/{id}',
  ),
])
_sym_db.RegisterServiceDescriptor(_PIPELINECOMPONENTSERVICE)

DESCRIPTOR.services_by_name['PipelineComponentService'] = _PIPELINECOMPONENTSERVICE

# @@protoc_insertion_point(module_scope)
