# coding: utf-8

"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.pipelinecomponents
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_get_component_by_name_response import CodegenGetComponentByNameResponse  # noqa: E501
from kaistack.clients.openapi_clients.pipelinecomponents.rest import ApiException

class TestCodegenGetComponentByNameResponse(unittest.TestCase):
    """CodegenGetComponentByNameResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetComponentByNameResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_get_component_by_name_response.CodegenGetComponentByNameResponse()  # noqa: E501
        if include_optional :
            return CodegenGetComponentByNameResponse(
                component = kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_pipeline_component.codegenPipelineComponent(
                    id = '0', 
                    name = '0', 
                    description = '0', 
                    image = '0', 
                    creator = '0', 
                    version = '0', 
                    help_link = '0', 
                    spec = '0', 
                    sha256 = '0', 
                    created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                error = '0'
            )
        else :
            return CodegenGetComponentByNameResponse(
        )

    def testCodegenGetComponentByNameResponse(self):
        """Test CodegenGetComponentByNameResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
