# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.workflow.configuration import Configuration


class CodegenGetArtifactsFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'experiment': 'str',
        'pipeline_run_id': 'str',
        'run_id': 'str'
    }

    attribute_map = {
        'experiment': 'experiment',
        'pipeline_run_id': 'pipelineRunId',
        'run_id': 'runId'
    }

    def __init__(self, experiment=None, pipeline_run_id=None, run_id=None, local_vars_configuration=None):  # noqa: E501
        """CodegenGetArtifactsFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._experiment = None
        self._pipeline_run_id = None
        self._run_id = None
        self.discriminator = None

        if experiment is not None:
            self.experiment = experiment
        if pipeline_run_id is not None:
            self.pipeline_run_id = pipeline_run_id
        if run_id is not None:
            self.run_id = run_id

    @property
    def experiment(self):
        """Gets the experiment of this CodegenGetArtifactsFilter.  # noqa: E501


        :return: The experiment of this CodegenGetArtifactsFilter.  # noqa: E501
        :rtype: str
        """
        return self._experiment

    @experiment.setter
    def experiment(self, experiment):
        """Sets the experiment of this CodegenGetArtifactsFilter.


        :param experiment: The experiment of this CodegenGetArtifactsFilter.  # noqa: E501
        :type: str
        """

        self._experiment = experiment

    @property
    def pipeline_run_id(self):
        """Gets the pipeline_run_id of this CodegenGetArtifactsFilter.  # noqa: E501


        :return: The pipeline_run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_run_id

    @pipeline_run_id.setter
    def pipeline_run_id(self, pipeline_run_id):
        """Sets the pipeline_run_id of this CodegenGetArtifactsFilter.


        :param pipeline_run_id: The pipeline_run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :type: str
        """

        self._pipeline_run_id = pipeline_run_id

    @property
    def run_id(self):
        """Gets the run_id of this CodegenGetArtifactsFilter.  # noqa: E501


        :return: The run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this CodegenGetArtifactsFilter.


        :param run_id: The run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenGetArtifactsFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenGetArtifactsFilter):
            return True

        return self.to_dict() != other.to_dict()
