# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.workflow
from kaistack.clients.openapi_clients.workflow.models.codegen_get_argo_workflow_response import CodegenGetArgoWorkflowResponse  # noqa: E501
from kaistack.clients.openapi_clients.workflow.rest import ApiException

class TestCodegenGetArgoWorkflowResponse(unittest.TestCase):
    """CodegenGetArgoWorkflowResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetArgoWorkflowResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.workflow.models.codegen_get_argo_workflow_response.CodegenGetArgoWorkflowResponse()  # noqa: E501
        if include_optional :
            return CodegenGetArgoWorkflowResponse(
                workflow = kaistack.clients.openapi_clients.workflow.models.codegen_argo_workflow.codegenArgoWorkflow(
                    name = '0', )
            )
        else :
            return CodegenGetArgoWorkflowResponse(
        )

    def testCodegenGetArgoWorkflowResponse(self):
        """Test CodegenGetArgoWorkflowResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
